# Python Canonical Datamodel Library

The `canonical` namespace contains sub-packages that define commonly used
datastructures, for example as defined in a Request for Comments (RFC). Each
model is implemented using `pydantic`.
